@@ -95,10 +95,11 @@ from kivy.properties import (                               # type: ignore # pyl
     ListProperty, ObjectProperty, StringProperty)
 from kivy.uix.widget import Widget                          # type: ignore
 
+from ae.base import norm_path                               # type: ignore
 from ae.kivy_app import FlowDropDown                        # type: ignore
 
 
-__version__ = '0.2.9'
+__version__ = '0.3.9'
 
 
 Builder.load_string('''\
@@ -147,8 +148,8 @@ Builder.load_string('''\
 
 <FileChooserPathSelectPopup>
     paths:
-        [norm_path(path) for path in set(list(PATH_PLACEHOLDERS.values()) + app.app_states['file_chooser_paths']) \
-        if os.path.exists(norm_path(path)) and os.path.isdir(norm_path(path))]
+        [normalize(path) for path in set(list(PATH_PLACEHOLDERS.values()) + app.app_states['file_chooser_paths']) \
+        if os.path.exists(normalize(path)) and os.path.isdir(normalize(path))]
     on_paths: app.main_app.change_app_state('file_chooser_paths', list(self.paths))
     on_select: self.attach_to.parent.parent.parent.initial_path = args[1]
     child_data_maps:
@@ -212,7 +213,7 @@ class FileChooserPopup(FlowDropDown):
         :param file_path:       file path (mostly the last just selected file) of which the folder will be registered.
         :param main_app:        main app instance.
         """
-        folder = os.path.abspath(os.path.dirname(file_path))
+        folder = os.path.dirname(norm_path(file_path))
         main_app.change_app_state('file_chooser_initial_path', folder)
         if folder not in main_app.file_chooser_paths:
             main_app.file_chooser_paths.insert(0, folder)
